/*
 * Copyright 2016 University of Chicago
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * @file stat.c
 * Implementation of the s3 DSI stat
 */

#include "globus_gridftp_server_s3_stat.h"

void
globus_i_s3_stat_root(
    globus_i_s3_stat_t                 *stat_info)
{
    int                                 dev;
    int                                 ino;

    /* If user asks for stat of /, we don't have any real information,
     * so we finish with a dummy  entry for "."
     */
    dev = globus_hashtable_string_hash("/", INT_MAX);
    ino = globus_hashtable_string_hash("/", INT_MAX);

    globus_i_s3_stat_add(
            stat_info,
            &(globus_gfs_stat_t)
            {
                .mode         = S_IRWXU|S_IFDIR,
                .nlink        = 1,
                .name         = ".",
                .dev          = dev,
                .ino          = ino,
                .mtime        = (time_t) -1,
                .atime        = (time_t) -1,
                .ctime        = (time_t) -1
            });

    return;
}
/* globus_i_s3_stat_root() */
// vim: ft=c:
